@@ -28,14 +28,19 @@
 		FILE_SHARE_READ | FILE_SHARE_WRITE, NULL, OPEN_EXISTING, 	\
 		FILE_ATTRIBUTE_NORMAL, NULL)
 #define CloseFile(_fhandle_) 	CloseHandle(_fhandle_)
+#define TruncateFile(_filename_) \
+       CloseFile(CreateFile(_filename_, GENERIC_WRITE, \
+		FILE_SHARE_READ | FILE_SHARE_WRITE, NULL, \
+                TRUNCATE_EXISTING, \
+		FILE_ATTRIBUTE_NORMAL, NULL))
 //#define MoveFile(_oldfile_, _newfile_)     MoveFile(_oldfile_, _newfile_)
-//#define CloseFile(_file_)   	CloseHandle(file)
 #define INVALID_FHANDLE 	INVALID_HANDLE_VALUE
 #elif __UNIX__
 
 #define FHANDLE	int
-#define OpenFile(_filename_)	open(_filename_, O_RDWR | O_CREAT, S_IRWXU | S_IRGRP | S_IROTH)
+#define OpenFile(_filename_)	open(_filename_, O_RDWR | O_CREAT, S_IRUSR | S_IWUSR | S_IRGRP | S_IROTH)
 #define CloseFile(_fhandle_) 	close(_fhandle_)
+#define TruncateFile(_filename_)	CloseFile(open(_filename_, O_RDWR | O_CREAT | O_TRUNC, S_IRUSR | S_IWUSR | S_IRGRP | S_IROTH))
 #define MoveFile(_oldfile_, _newfile_)     rename(_oldfile_, _newfile_)
 #define DeleteFile(_file_)  	(!unlink(_file_))
 #define INVALID_FHANDLE 	-1
@@ -43,7 +48,6 @@
 #endif 
 
 // Thread Routines
-////////////////////////////////////////// 
 #if WIN32
 #define THANDLE	HANDLE
 #define BeginThread(_thandle_, callback) \
@@ -56,7 +60,6 @@
 #define	SemWait(_s_)	{WaitForSingleObject(_s_, INFINITE); ResetEvent(_s_);}
 #define	SemPost(_s_)	SetEvent(_s_)
 #define	SemDestroy(_s_)	CloseHandle(_s_)
-#define SemIsSignaled(_s_, _b_)	{*_b_ = (WaitForSingleObject(_s_, 0) == WAIT_OBJECT_0);}
 
 
 #elif __UNIX__
@@ -71,8 +74,7 @@
 #define	SemWait(_s_)	sem_wait(&(_s_))
 #define	SemPost(_s_)	sem_post(&(_s_))
 #define	SemDestroy(_s_)	sem_destroy(&(_s_))
-#define SemIsSignaled(_s_, _b_)	sem_getvalue(&(_s_), _b_)
-#define Sleep(x) 	usleep(x)	
+#define Sleep(x) 	usleep(1000*x)	
 
 #endif
 
@@ -88,4 +90,11 @@
 #define WSACleanup()
 #endif
 
+// Other stuff
+////////////////////////////////////////// 
+
+#if WIN32
+#define snprintf _snprintf
+#endif
+
 #endif // __COMPAT_H__
