@@ -36,7 +36,6 @@
 		_beginthread((void *)callback, 0, (void *)NULL)
 #elif __UNIX__
     #include <unistd.h>
-	#define Sleep(x) usleep(x)
 	#define beginthread(thread, callback) \
 		pthread_create(thread, NULL, \
                           (void *)callback, (void *)NULL)
@@ -55,13 +54,10 @@ HSEM		threadlib_create_sem();
 error_code	threadlib_waitfor_sem(HSEM *e);
 error_code	threadlib_signel_sem(HSEM *e);
 void		threadlib_destroy_sem(HSEM *e);
-BOOL		threadlib_sem_signaled(HSEM *e);
 
 
 error_code threadlib_beginthread(THREAD_HANDLE *thread, void (*callback)(void *))
 {
-	DEBUG1(("starting thread"));
-
 	BeginThread(thread->thread_handle, callback);
 	//if (thread->thread_handle == NULL)	// don't feel like porting this
 	//	return SR_ERROR_CANT_CREATE_THREAD;
@@ -81,13 +77,6 @@ HSEM threadlib_create_sem()
 	return s;
 }
 
-BOOL threadlib_sem_signaled(HSEM *e)
-{
-	int sig = 0;
-	SemIsSignaled(*e, &sig);
-	return (BOOL)sig;
-}
-
 error_code threadlib_waitfor_sem(HSEM *e)
 {
 	if (!e)
