@@ -4,13 +4,20 @@
 ////////////////////////////////////////////////
 // Types
 ////////////////////////////////////////////////
-
+#include "srconfig.h"
 #if WIN32
 #include <windows.h>
 #else
 #include <sys/types.h>
 #endif
 
+#if HAVE_WCHAR_H
+#include <wchar.h>
+#endif
+#if STDC_HEADERS
+#include <stddef.h>
+#endif
+
 typedef int error_code;
 #define BOOL	int
 #define TRUE	1
@@ -18,17 +25,22 @@ typedef int error_code;
 
 #define NO_META_INTERVAL	-1
 
+/* GCS - Grr. I don't care.  Max path is 254 until I get around to
+    fixing this for other platforms. */
+#define SR_MAX_PATH		254
 #define MAX_HOST_LEN		512
 #define MAX_IP_LEN			3+1+3+1+3+1+3+1
-#define MAX_PATH_LEN		8192
 #define MAX_HEADER_LEN		8192
-#define MAX_URL_LEN			MAX_HOST_LEN+MAX_PATH_LEN
+#define MAX_URL_LEN			8192
 #define MAX_ICY_STRING		4024
 #define MAX_SERVER_LEN		1024
-#define MAX_TRACK_LEN		1024
+//#define MAX_TRACK_LEN		MAX_PATH
+#define MAX_TRACK_LEN		SR_MAX_PATH /* GCS - be careful here... */
 #define MAX_URI_STRING		1024
-#define MAX_ERROR_STR       (4096)
+#define MAX_ERROR_STR           (4096)
 #define MAX_USERAGENT_STR	1024
+#define MAX_AUTH_LEN            255
+//#define MAX_DROPSTRING_LEN      255
 
 #ifdef WIN32
 	#ifndef _WINSOCKAPI_
@@ -41,14 +53,22 @@ typedef unsigned long u_long;
 typedef unsigned char u_char;
 typedef unsigned short u_short;
 #endif
- 
+
+/* Different types of streams */
+#define CONTENT_TYPE_MP3		1
+#define CONTENT_TYPE_NSV		2
+#define CONTENT_TYPE_OGG    		3
+#define CONTENT_TYPE_ULTRAVOX		4
+#define CONTENT_TYPE_AAC		5
+#define CONTENT_TYPE_UNKNOWN		99
+
 /* 
  * IO_DATA_INPUT is a interface for socket input data, it has one 
  * method 'get_data' and is called by a "ripper" which is effectivly 
  * only ripshout.c (and the R.I.P. riplive365.c)
  */
 typedef struct IO_DATA_INPUTst{
-	int (*get_data)(char* buffer, int size);
+	int (*get_input_data)(char* buffer, int size);
 } IO_DATA_INPUT;
 
 #define NO_TRACK_STR	"No track info..."
@@ -59,22 +79,55 @@ typedef struct IO_DATA_INPUTst{
  * does the "find silent point" shit.
  */
 typedef struct IO_GET_STREAMst{
-	int (*get_data)(char* buffer, char *track);
+	int (*get_stream_data)(char* data_buf, char *track_buf);
 	u_long getsize;
 } IO_GET_STREAM;
 
-
+/* 
+ * SPLITPOINT_OPTIONS are the options used to tweek how the silence 
+ * separation is done.
+ */
+typedef struct SPLITPOINT_OPTIONSst
+{
+    int	xs;
+    int xs_min_volume;
+    int xs_silence_length;
+    int xs_search_window_1;
+    int xs_search_window_2;
+    int xs_offset;
+    //int xd_offset;
+    //int xpadding_1;
+    //int xpadding_2;
+    int xs_padding_1;
+    int xs_padding_2;
+} SPLITPOINT_OPTIONS;
 
 /* 
- * IO_PUT_STREAM is the 'output final shit' interface. effectivly however 
- * it's just a interface for filelib. it's only called from ripstream.c
+ * CODESET_OPTIONS are the options used to decide how to parse
+ * and convert the metadata
  */
-typedef struct IO_PUT_STREAMst{
-	error_code (*put_data)(char* buffer, int size);
-	error_code (*start_track)(char* trackname);			// track name or '\0'
-	error_code (*end_track)(char* trackname);			// track name or '\0'
-} IO_PUT_STREAM;
-	
+typedef struct CODESET_OPTIONSst
+{
+    char* codeset;
+} CODESET_OPTIONS;
+
+/* 
+ * TRACK_INFO is the parsed metadata
+ */
+#if HAVE_WCHAR_T
+typedef char mchar;
+#else
+typedef wchar_t mchar;
+#endif
+typedef struct TRACK_INFOst
+{
+    int have_track_info;
+    char raw_metadata[MAX_TRACK_LEN];
+    char artist[MAX_TRACK_LEN];
+    char title[MAX_TRACK_LEN];
+    char album[MAX_TRACK_LEN];
+} TRACK_INFO;
+
 
 ////////////////////////////////////////////////
 // StreamRipper Codes
@@ -83,7 +136,7 @@ typedef struct IO_PUT_STREAMst{
 // are not organized at all, should have space to insert in places.
 //
 /* ******************** IMPORTANT IF YOU ADD ERROR CODES!!!! *****************************/
-#define NUM_ERROR_CODES					0x38+1
+#define NUM_ERROR_CODES					0x3c+1
 /* ******************** IMPORTANT IF YOU ADD ERROR CODES!!!! *****************************/
 #define SR_SUCCESS					0x00
 #define SR_SUCCESS_BUFFERING				0x01
@@ -118,6 +171,7 @@ typedef struct IO_PUT_STREAMst{
 #define SR_ERROR_NO_TRACK_INFO				-	0x1D
 #define SR_EEROR_CANT_FIND_SUBSTR			-	0x1E
 #define SR_ERROR_CANT_BIND_ON_PORT			-	0x1F
+#define SR_ERROR_CANT_BIND_ON_INTERFACE		-	0x40
 #define SR_ERROR_HOST_NOT_CONNECTED			-	0x20
 #define SR_ERROR_HTTP_404_ERROR				-	0x21
 #define SR_ERROR_HTTP_401_ERROR				-	0x22	
@@ -143,5 +197,9 @@ typedef struct IO_PUT_STREAMst{
 #define SR_ERROR_NOT_SHOUTCAST_STREAM		-	0x36
 #define SR_ERROR_HTTP_407_ERROR				-	0x37
 #define	SR_ERROR_HTTP_403_ERROR				-	0x38
+#define SR_ERROR_DIR_PATH_TOO_LONG			-	0x39
+#define SR_ERROR_PROGRAM_ERROR				-	0x3a
+#define SR_ERROR_TIMEOUT                        -  0x3b
+#define SR_ERROR_SELECT_FAILED                  -  0x3c
 
 #endif //__SRIPPER_H__
